import axios, {AxiosError} from 'axios'

/* Base domain for all request */ 
export const baseURL = import.meta.env.VITE_URL_DOCUMENT

/* Config Client*/
const Client = axios.create({
  baseURL: baseURL,
  headers: {
    Accept: 'application/json',
  },
})

Client.interceptors.response.use(
  (response) => {
    // Any status code that lie within the range of 2xx cause this function to trigger
    // Do something with response data
    return response
  },
  (error: AxiosError<any>) => {
    const msg = error.response && error.response.data && error.response.data.error ?
      error.response.data.error.message :  'Unexpected error'
    const code = error.code ? Number(error.response?.status) : 500
    const standardizedError = new SimpleError(code, msg)
    
    return Promise.reject(standardizedError)
  }
)

export interface ISimpleError extends Error {
  code : number
}

class SimpleError extends Error implements ISimpleError {
  code : number
  constructor(code: number, message:string) {
    super(message)
    this.code = code
  }
}

export default Client